@@ -63,14 +63,14 @@ class ViewAction(InterfaceAction):
         cm = partial(self.create_menu_action, self.view_menu)
         self.view_specific_action = cm('specific', _('View specific format'),
                 shortcut='Alt+V', triggered=self.view_specific_format)
-        self.internal_view_action = cm('internal', _('View with calibre E-book viewer'), triggered=self.view_internal)
+        self.internal_view_action = cm('internal', _('View with calibre E-book viewer'), icon='viewer.png', triggered=self.view_internal)
         self.action_pick_random = cm('pick random', _('Read a random book'),
                 icon='random.png', triggered=self.view_random)
         self.view_menu.addAction(QIcon(I('highlight.png')), _('Browse annotations'), self.browse_annots)
         self.clear_sep1 = self.view_menu.addSeparator()
         self.clear_sep2 = self.view_menu.addSeparator()
         self.clear_history_action = cm('clear history',
-                _('Clear recently viewed list'), triggered=self.clear_history)
+                _('Clear recently viewed list'), icon='trash.png', triggered=self.clear_history)
         self.history_actions = [self.clear_sep1]
         self.action_view_last_read = ac = self.create_action(
             spec=(_('Continue reading previous book'), None, _('Continue reading the last opened book'), 'shift+v'), attr='action_view_last_read')
@@ -148,6 +148,9 @@ class ViewAction(InterfaceAction):
             title = db.title(id_, index_is_id=True)
             self._view_file(fmt_path, calibre_book_data=self.calibre_book_data(id_, format), open_at=open_at)
             self.update_history([(id_, title)])
+        else:
+            error_dialog(self.gui, _('E-book file missing'), _(
+                'The {} format file is missing from the calibre library folder').format(format), show=True)
 
     def book_downloaded_for_viewing(self, job):
         if job.failed:
@@ -165,12 +168,13 @@ class ViewAction(InterfaceAction):
 
                 if name is not None:
                     args.append(name)
-                    if open_at is not None:
-                        args.append('--open-at=' + open_at)
-                    if calibre_book_data is not None:
-                        with PersistentTemporaryFile('.json') as ptf:
-                            ptf.write(as_bytes(json.dumps(calibre_book_data)))
-                            args.append('--internal-book-data=' + ptf.name)
+                    if viewer != 'lrfviewer':
+                        if open_at is not None:
+                            args.append('--open-at=' + open_at)
+                        if calibre_book_data is not None:
+                            with PersistentTemporaryFile('.json') as ptf:
+                                ptf.write(as_bytes(json.dumps(calibre_book_data)))
+                                args.append('--internal-book-data=' + ptf.name)
                 self.gui.job_manager.launch_gui_app(viewer,
                         kwargs=dict(args=args))
             else:
